@@ -1,3 +1,11 @@
+#ifndef R_NO_REMAP
+#  define R_NO_REMAP
+#endif
+
+#ifndef R_NO_REMAP
+#  define R_NO_REMAP
+#endif
+
 #include <R.h>
 #include <Rinternals.h>
 
