@@ -1,3 +1,7 @@
+#ifndef R_NO_REMAP
+#  define R_NO_REMAP
+#endif
+
 #define USE_FC_LEN_T
 #include <algorithm>
 #include <string>
@@ -179,12 +183,12 @@ extern "C" {
     //return stuff  
     SEXP w_r, samples_r, accept_r, accept_w_r, tuning_r, tuning_w_r;
     
-    PROTECT(w_r = allocMatrix(REALSXP, n, nSamples)); nProtect++;  
-    PROTECT(samples_r = allocMatrix(REALSXP, nParams, nSamples)); nProtect++; 
-    PROTECT(accept_r = allocMatrix(REALSXP, nParams, nBatch)); nProtect++;
-    PROTECT(accept_w_r = allocMatrix(REALSXP, n, nBatch)); nProtect++;
-    PROTECT(tuning_r = allocMatrix(REALSXP, nParams, nBatch)); nProtect++;
-    PROTECT(tuning_w_r = allocMatrix(REALSXP, n, nBatch)); nProtect++;
+    PROTECT(w_r = Rf_allocMatrix(REALSXP, n, nSamples)); nProtect++;  
+    PROTECT(samples_r = Rf_allocMatrix(REALSXP, nParams, nSamples)); nProtect++; 
+    PROTECT(accept_r = Rf_allocMatrix(REALSXP, nParams, nBatch)); nProtect++;
+    PROTECT(accept_w_r = Rf_allocMatrix(REALSXP, n, nBatch)); nProtect++;
+    PROTECT(tuning_r = Rf_allocMatrix(REALSXP, nParams, nBatch)); nProtect++;
+    PROTECT(tuning_w_r = Rf_allocMatrix(REALSXP, n, nBatch)); nProtect++;
 
     /*****************************************
        Set-up MCMC alg. vars. matrices etc.
@@ -241,9 +245,9 @@ extern "C" {
 
 	  //invert C and log det cov
 	  detCand = 0;
-	  F77_NAME(dpotrf)(lower, &n, C, &n, &info FCONE); if(info != 0){error("c++ error: Cholesky failed in spGLM\n");}
+	  F77_NAME(dpotrf)(lower, &n, C, &n, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: Cholesky failed in spGLM\n");}
 	  for(k = 0; k < n; k++) detCand += 2*log(C[k*n+k]);
-	  F77_NAME(dpotri)(lower, &n, C, &n, &info FCONE); if(info != 0){error("c++ error: Cholesky inverse failed in spGLM\n");}
+	  F77_NAME(dpotri)(lower, &n, C, &n, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: Cholesky inverse failed in spGLM\n");}
 	  
 	  //Likelihood with Jacobian  
 	  logPostCand = 0.0;
@@ -269,7 +273,7 @@ extern "C" {
 	  }else if(family == "poisson"){
 	    logPostCand += poisson_logpost(n, Y, tmp_n, w, weights);
 	  }else{
-	    error("c++ error: family misspecification in spGLM\n");
+	    Rf_error("c++ Rf_error: family misspecification in spGLM\n");
 	  }
 	  
 	  //(-1/2) * tmp_n` *  C^-1 * tmp_n
@@ -310,9 +314,9 @@ extern "C" {
 
 	//invert C and log det cov
 	detCand = 0;
-	F77_NAME(dpotrf)(lower, &n, C, &n, &info FCONE); if(info != 0){error("c++ error: Cholesky failed in spGLM\n");}
+	F77_NAME(dpotrf)(lower, &n, C, &n, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: Cholesky failed in spGLM\n");}
 	for(k = 0; k < n; k++) detCand += 2*log(C[k*n+k]);
-	F77_NAME(dpotri)(lower, &n, C, &n, &info FCONE); if(info != 0){error("c++ error: Cholesky inverse failed in spGLM\n");}
+	F77_NAME(dpotri)(lower, &n, C, &n, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: Cholesky inverse failed in spGLM\n");}
 	
 	F77_NAME(dgemv)(ntran, &n, &p, &one, X, &n, beta, &incOne, &zero, tmp_n, &incOne FCONE);
 	  
@@ -344,7 +348,7 @@ extern "C" {
 	  }else if(family == "poisson"){
 	    logPostCand += poisson_logpost(n, Y, tmp_n, w, weights);
 	  }else{
-	    error("c++ error: family misspecification in spGLM\n");
+	    Rf_error("c++ Rf_error: family misspecification in spGLM\n");
 	  }
 	  
 	  //(-1/2) * tmp_n` *  C^-1 * tmp_n
@@ -451,29 +455,29 @@ extern "C" {
     
     int nResultListObjs = 6;
     
-    PROTECT(result = allocVector(VECSXP, nResultListObjs)); nProtect++;
-    PROTECT(resultNames = allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(result = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(resultNames = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
 
     //samples
     SET_VECTOR_ELT(result, 0, samples_r);
-    SET_VECTOR_ELT(resultNames, 0, mkChar("p.beta.theta.samples")); 
+    SET_VECTOR_ELT(resultNames, 0, Rf_mkChar("p.beta.theta.samples")); 
 
     SET_VECTOR_ELT(result, 1, accept_r);
-    SET_VECTOR_ELT(resultNames, 1, mkChar("acceptance"));
+    SET_VECTOR_ELT(resultNames, 1, Rf_mkChar("acceptance"));
 
     SET_VECTOR_ELT(result, 2, accept_w_r);
-    SET_VECTOR_ELT(resultNames, 2, mkChar("acceptance.w"));
+    SET_VECTOR_ELT(resultNames, 2, Rf_mkChar("acceptance.w"));
     
     SET_VECTOR_ELT(result, 3, w_r);
-    SET_VECTOR_ELT(resultNames, 3, mkChar("p.w.samples"));
+    SET_VECTOR_ELT(resultNames, 3, Rf_mkChar("p.w.samples"));
 
     SET_VECTOR_ELT(result, 4, tuning_r);
-    SET_VECTOR_ELT(resultNames, 4, mkChar("tuning"));
+    SET_VECTOR_ELT(resultNames, 4, Rf_mkChar("tuning"));
 
     SET_VECTOR_ELT(result, 5, tuning_w_r);
-    SET_VECTOR_ELT(resultNames, 5, mkChar("tuning.w"));
+    SET_VECTOR_ELT(resultNames, 5, Rf_mkChar("tuning.w"));
   
-    namesgets(result, resultNames);
+    Rf_namesgets(result, resultNames);
    
     //unprotect
     UNPROTECT(nProtect);
