@@ -1,3 +1,7 @@
+#ifndef R_NO_REMAP
+#  define R_NO_REMAP
+#endif
+
 #define USE_FC_LEN_T
 #include <algorithm>
 #include <string>
@@ -97,7 +101,7 @@ extern "C" {
       if(amcmc){
 	Rprintf("Using adaptive MCMC.\n\n");
 	Rprintf("\tNumber of batches %i.\n", nBatch);
-	Rprintf("\tBatch length %i.\n", batchLength);
+	Rprintf("\tBatch Rf_length %i.\n", batchLength);
 	Rprintf("\tTarget acceptance rate %.5f.\n", acceptRate);
 	Rprintf("\n");
       }else{
@@ -199,13 +203,13 @@ extern "C" {
 
     //return stuff  
     SEXP samples_r, accept_r, tuning_r;
-    PROTECT(samples_r = allocMatrix(REALSXP, nParams, nSamples)); nProtect++; 
+    PROTECT(samples_r = Rf_allocMatrix(REALSXP, nParams, nSamples)); nProtect++; 
 
     if(amcmc){
-      PROTECT(accept_r = allocMatrix(REALSXP, nParams, nBatch)); nProtect++; 
-      PROTECT(tuning_r = allocMatrix(REALSXP, nParams, nBatch)); nProtect++; 
+      PROTECT(accept_r = Rf_allocMatrix(REALSXP, nParams, nBatch)); nProtect++; 
+      PROTECT(tuning_r = Rf_allocMatrix(REALSXP, nParams, nBatch)); nProtect++; 
     }else{
-      PROTECT(accept_r = allocMatrix(REALSXP, 1, floor(static_cast<double>(nSamples/nReport)))); nProtect++; 
+      PROTECT(accept_r = Rf_allocMatrix(REALSXP, 1, floor(static_cast<double>(nSamples/nReport)))); nProtect++; 
     }
 
     /*****************************************
@@ -307,7 +311,7 @@ extern "C" {
 	    }
 
 	    det = 0;
-	    F77_NAME(dpotrf)(lower, &n, Cbeta, &n, &info FCONE); if(info != 0){error("c++ error: dpotrf failed\n");}
+	    F77_NAME(dpotrf)(lower, &n, Cbeta, &n, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: dpotrf failed\n");}
 	    for(k = 0; k < n; k++) det += 2*log(Cbeta[k*n+k]);
 	    
 	    F77_NAME(dcopy)(&n, z, &incOne, tmp_n, &incOne);
@@ -316,7 +320,7 @@ extern "C" {
 	    Q = pow(F77_NAME(dnrm2)(&n, tmp_n, &incOne),2);
 	  }else{//beta flat
 	    det = 0;
-	    F77_NAME(dpotrf)(lower, &n, C, &n, &info FCONE); if(info != 0){error("c++ error: dpotrf failed\n");}
+	    F77_NAME(dpotrf)(lower, &n, C, &n, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: dpotrf failed\n");}
 	    for(k = 0; k < n; k++) det += 2*log(C[k*n+k]);
 	    
 	    F77_NAME(dcopy)(&n, Y, &incOne, vU, &incOne);
@@ -324,7 +328,7 @@ extern "C" {
 	    F77_NAME(dtrsm)(lside, lower, ntran, nUnit, &n, &p1, &one, C, &n, vU, &n FCONE FCONE FCONE FCONE);//L[v:U] = [y:X]
 
 	    F77_NAME(dgemm)(ytran, ntran, &p, &p, &n, &one, &vU[n], &n, &vU[n], &n, &zero, tmp_pp, &p FCONE FCONE); //U'U
-	    F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE); if(info != 0){error("c++ error: dpotrf failed\n");}
+	    F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: dpotrf failed\n");}
 	    for(k = 0; k < p; k++) det += 2*log(tmp_pp[k*p+k]);
 	    
 	    F77_NAME(dgemv)(ytran, &n, &p, &one, &vU[n], &n, vU, &incOne, &zero, tmp_p, &incOne FCONE); //U'v
@@ -464,22 +468,22 @@ extern "C" {
       nResultListObjs++;
     }
     
-    PROTECT(result_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
-    PROTECT(resultName_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(result_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(resultName_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
 
     //samples
     SET_VECTOR_ELT(result_r, 0, samples_r);
-    SET_VECTOR_ELT(resultName_r, 0, mkChar("p.theta.samples")); 
+    SET_VECTOR_ELT(resultName_r, 0, Rf_mkChar("p.theta.samples")); 
 
     SET_VECTOR_ELT(result_r, 1, accept_r);
-    SET_VECTOR_ELT(resultName_r, 1, mkChar("acceptance"));
+    SET_VECTOR_ELT(resultName_r, 1, Rf_mkChar("acceptance"));
 
     if(amcmc){
       SET_VECTOR_ELT(result_r, 2, tuning_r);
-      SET_VECTOR_ELT(resultName_r, 2, mkChar("tuning"));
+      SET_VECTOR_ELT(resultName_r, 2, Rf_mkChar("tuning"));
     }
 
-    namesgets(result_r, resultName_r);
+    Rf_namesgets(result_r, resultName_r);
    
     //unprotect
     UNPROTECT(nProtect);
