@@ -1,3 +1,7 @@
+#ifndef R_NO_REMAP
+#  define R_NO_REMAP
+#endif
+
 #define USE_FC_LEN_T
 #include <string>
 // #ifdef _OPENMP
@@ -221,13 +225,13 @@ extern "C" {
     //samples and random effects
     SEXP w_r, samples_r, accept_r;
 
-    PROTECT(w_r = allocMatrix(REALSXP, nm, nSamples)); nProtect++; 
+    PROTECT(w_r = Rf_allocMatrix(REALSXP, nm, nSamples)); nProtect++; 
     double *w = REAL(w_r); zeros(w, nm*nSamples);
 
-    PROTECT(samples_r = allocMatrix(REALSXP, nParams, nSamples)); nProtect++; 
+    PROTECT(samples_r = Rf_allocMatrix(REALSXP, nParams, nSamples)); nProtect++; 
     double *samples = REAL(samples_r);
 
-    PROTECT(accept_r = allocMatrix(REALSXP, 1, 1)); nProtect++;
+    PROTECT(accept_r = Rf_allocMatrix(REALSXP, 1, 1)); nProtect++;
 
     /*****************************************
        Set-up MCMC alg. vars. matrices etc.
@@ -307,9 +311,9 @@ extern "C" {
 
       //invert C and log det cov
       detCand = 0;
-      F77_NAME(dpotrf)(lower, &nm, C, &nm, &info FCONE); if(info != 0){error("c++ error: dpotrf failed\n");}
+      F77_NAME(dpotrf)(lower, &nm, C, &nm, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: dpotrf failed\n");}
       for(i = 0; i < nm; i++) detCand += 2*log(C[i*nm+i]);
-      F77_NAME(dpotri)(lower, &nm, C, &nm, &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
+      F77_NAME(dpotri)(lower, &nm, C, &nm, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: dpotri failed\n");}
       
       //Likelihood with Jacobian   
       logPostCand = 0.0;
@@ -330,7 +334,7 @@ extern "C" {
       for(i = 0; i < m; i++) logPostCand += (m-i)*log(A[i*m+i])+log(A[i*m+i]);
       
       //get S*K^-1, already have the chol of K (i.e., A)
-      F77_NAME(dpotri)(lower, &m, A, &m, &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
+      F77_NAME(dpotri)(lower, &m, A, &m, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: dpotri failed\n");}
       F77_NAME(dsymm)(rside, lower, &m, &m, &one, A, &m, KIW_S, &m, &zero, tmp_mm, &m FCONE FCONE);
       for(i = 0; i < m; i++){SKtrace += tmp_mm[i*m+i];}
       logPostCand += -0.5*(KIW_df+m+1)*logDetK - 0.5*SKtrace;
@@ -350,7 +354,7 @@ extern "C" {
       }else if(family == "poisson"){
 	logPostCand += poisson_logpost(nm, Y, tmp_nm, wCand, weights);
       }else{
-	error("c++ error: family misspecification in spGLM\n");
+	Rf_error("c++ Rf_error: family misspecification in spGLM\n");
       }
 
       //(-1/2) * tmp_n` *  C^-1 * tmp_n
@@ -431,20 +435,20 @@ extern "C" {
     
     int nResultListObjs = 3;
 
-    PROTECT(result = allocVector(VECSXP, nResultListObjs)); nProtect++;
-    PROTECT(resultNames = allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(result = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(resultNames = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
 
    //samples
     SET_VECTOR_ELT(result, 0, samples_r);
-    SET_VECTOR_ELT(resultNames, 0, mkChar("p.beta.theta.samples")); 
+    SET_VECTOR_ELT(resultNames, 0, Rf_mkChar("p.beta.theta.samples")); 
 
     SET_VECTOR_ELT(result, 1, accept_r);
-    SET_VECTOR_ELT(resultNames, 1, mkChar("acceptance"));
+    SET_VECTOR_ELT(resultNames, 1, Rf_mkChar("acceptance"));
     
     SET_VECTOR_ELT(result, 2, w_r);
-    SET_VECTOR_ELT(resultNames, 2, mkChar("p.w.samples"));
+    SET_VECTOR_ELT(resultNames, 2, Rf_mkChar("p.w.samples"));
   
-    namesgets(result, resultNames);
+    Rf_namesgets(result, resultNames);
    
     //unprotect
     UNPROTECT(nProtect);
