@@ -1,3 +1,7 @@
+#ifndef R_NO_REMAP
+#  define R_NO_REMAP
+#endif
+
 #define USE_FC_LEN_T
 #include <algorithm>
 #include <string>
@@ -151,7 +155,7 @@ extern "C" {
       if(amcmc){
 	Rprintf("Using adaptive MCMC.\n\n");
 	Rprintf("\tNumber of batches %i.\n", nBatch);
-	Rprintf("\tBatch length %i.\n", batchLength);
+	Rprintf("\tBatch Rf_length %i.\n", batchLength);
 	Rprintf("\ttarget acceptance rate %.5f.\n", acceptRate);
 	Rprintf("\n");
       }else{
@@ -331,13 +335,13 @@ extern "C" {
 
     //return stuff  
     SEXP samples_r, accept_r, tuning_r;
-    PROTECT(samples_r = allocMatrix(REALSXP, nParams, nSamples)); nProtect++;
+    PROTECT(samples_r = Rf_allocMatrix(REALSXP, nParams, nSamples)); nProtect++;
     
     if(amcmc){
-      PROTECT(accept_r = allocMatrix(REALSXP, nParams, nBatch)); nProtect++; 
-      PROTECT(tuning_r = allocMatrix(REALSXP, nParams, nBatch)); nProtect++;  
+      PROTECT(accept_r = Rf_allocMatrix(REALSXP, nParams, nBatch)); nProtect++; 
+      PROTECT(tuning_r = Rf_allocMatrix(REALSXP, nParams, nBatch)); nProtect++;  
     }else{
-      PROTECT(accept_r = allocMatrix(REALSXP, 1, floor(static_cast<double>(nSamples/nReport)))); nProtect++; 
+      PROTECT(accept_r = Rf_allocMatrix(REALSXP, 1, floor(static_cast<double>(nSamples/nReport)))); nProtect++; 
     }
     /*****************************************
        Set-up MCMC alg. vars. matrices etc.
@@ -481,7 +485,7 @@ extern "C" {
 	    }
 	    
 	    det = 0;
-	    F77_NAME(dpotrf)(lower, &nm, Cbeta, &nm, &info FCONE); if(info != 0){error("c++ error: dpotrf failed\n");}
+	    F77_NAME(dpotrf)(lower, &nm, Cbeta, &nm, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: dpotrf failed\n");}
 	    for(k = 0; k < nm; k++) det += 2*log(Cbeta[k*nm+k]);
 	    
 	    F77_NAME(dcopy)(&nm, z, &incOne, tmp_nm, &incOne);
@@ -490,7 +494,7 @@ extern "C" {
 	    Q = pow(F77_NAME(dnrm2)(&nm, tmp_nm, &incOne),2);
 	  }else{//beta flat
 	    det = 0;
-	    F77_NAME(dpotrf)(lower, &nm, C, &nm, &info FCONE); if(info != 0){error("c++ error: dpotrf failed\n");}
+	    F77_NAME(dpotrf)(lower, &nm, C, &nm, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: dpotrf failed\n");}
 	    for(k = 0; k < nm; k++) det += 2*log(C[k*nm+k]);
 	    
 	    F77_NAME(dcopy)(&nm, Y, &incOne, vU, &incOne);
@@ -498,7 +502,7 @@ extern "C" {
 	    F77_NAME(dtrsm)(lside, lower, ntran, nUnit, &nm, &p1, &one, C, &nm, vU, &nm FCONE FCONE FCONE FCONE);//L^{-1}[v:U] = [y:X]
 	    
 	    F77_NAME(dgemm)(ytran, ntran, &p, &p, &nm, &one, &vU[nm], &nm, &vU[nm], &nm, &zero, tmp_pp, &p FCONE FCONE); //U'U
-	    F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE); if(info != 0){error("c++ error: dpotrf failed\n");}
+	    F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: dpotrf failed\n");}
 	    for(k = 0; k < p; k++) det += 2*log(tmp_pp[k*p+k]);
 	    
 	    F77_NAME(dgemv)(ytran, &nm, &p, &one, &vU[nm], &nm, vU, &incOne, &zero, tmp_p, &incOne FCONE); //U'v
@@ -522,7 +526,7 @@ extern "C" {
 	    for(k = 0; k < m; k++){logPostCand += (m-k)*log(A[k*m+k])+log(A[k*m+k]);}
 	    
 	    //S*K^-1
-	    F77_NAME(dpotri)(lower, &m, A, &m, &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
+	    F77_NAME(dpotri)(lower, &m, A, &m, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: dpotri failed\n");}
 	    F77_NAME(dsymm)(rside, lower, &m, &m, &one, A, &m, KIW_S, &m, &zero, tmp_mm, &m FCONE FCONE);
 	    for(k = 0; k < m; k++){SKtrace += tmp_mm[k*m+k];}
 	    logPostCand += -0.5*(KIW_df+m+1)*logDetK - 0.5*SKtrace;
@@ -548,7 +552,7 @@ extern "C" {
 		for(k = 0; k < m; k++){logPostCand += (m-k)*log(L[k*m+k])+log(L[k*m+k]);}
 		
 		//get S*K^-1
-		F77_NAME(dpotri)(lower, &m, L, &m, &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
+		F77_NAME(dpotri)(lower, &m, L, &m, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: dpotri failed\n");}
 		F77_NAME(dsymm)(rside, lower, &m, &m, &one, L, &m, PsiIW_S, &m, &zero, tmp_mm, &m FCONE FCONE);
 		for(k = 0; k < m; k++){SKtrace += tmp_mm[k*m+k];}
 		logPostCand += -0.5*(PsiIW_df+m+1)*logDetK - 0.5*SKtrace;
@@ -714,22 +718,22 @@ extern "C" {
       nResultListObjs++;
     }
     
-    PROTECT(result_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
-    PROTECT(resultName_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(result_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(resultName_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
     
     //samples
     SET_VECTOR_ELT(result_r, 0, samples_r);
-    SET_VECTOR_ELT(resultName_r, 0, mkChar("p.theta.samples")); 
+    SET_VECTOR_ELT(resultName_r, 0, Rf_mkChar("p.theta.samples")); 
     
     SET_VECTOR_ELT(result_r, 1, accept_r);
-    SET_VECTOR_ELT(resultName_r, 1, mkChar("acceptance"));
+    SET_VECTOR_ELT(resultName_r, 1, Rf_mkChar("acceptance"));
     
     if(amcmc){
       SET_VECTOR_ELT(result_r, 2, tuning_r);
-      SET_VECTOR_ELT(resultName_r, 2, mkChar("tuning"));
+      SET_VECTOR_ELT(resultName_r, 2, Rf_mkChar("tuning"));
     }
     
-    namesgets(result_r, resultName_r);
+    Rf_namesgets(result_r, resultName_r);
     
     //unprotect
     UNPROTECT(nProtect);
