@@ -1,3 +1,7 @@
+#ifndef R_NO_REMAP
+#  define R_NO_REMAP
+#endif
+
 #define USE_FC_LEN_T
 #include <string>
 #include <R.h>
@@ -202,16 +206,16 @@ extern "C" {
     //samples and random effects
     SEXP w_r, w_str_r, samples_r, accept_r;
 
-    PROTECT(w_r = allocMatrix(REALSXP, n, nSamples)); nProtect++; 
+    PROTECT(w_r = Rf_allocMatrix(REALSXP, n, nSamples)); nProtect++; 
     double *w = REAL(w_r); zeros(w, n*nSamples);
 
-    PROTECT(w_str_r = allocMatrix(REALSXP, m, nSamples)); nProtect++; 
+    PROTECT(w_str_r = Rf_allocMatrix(REALSXP, m, nSamples)); nProtect++; 
     double *w_str = REAL(w_str_r); zeros(w_str, m*nSamples);
 
-    PROTECT(samples_r = allocMatrix(REALSXP, nParams, nSamples)); nProtect++; 
+    PROTECT(samples_r = Rf_allocMatrix(REALSXP, nParams, nSamples)); nProtect++; 
     double *samples = REAL(samples_r);
 
-    PROTECT(accept_r = allocMatrix(REALSXP, 1, 1)); nProtect++;
+    PROTECT(accept_r = Rf_allocMatrix(REALSXP, 1, 1)); nProtect++;
 
 
     /*****************************************
@@ -273,9 +277,9 @@ extern "C" {
     
       //invert C and log det cov
       detCand = 0;
-      F77_NAME(dpotrf)(lower, &m, K, &m, &info FCONE); if(info != 0){error("c++ error: Cholesky failed in spGLM\n");}
+      F77_NAME(dpotrf)(lower, &m, K, &m, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: Cholesky failed in spGLM\n");}
       for(i = 0; i < m; i++) detCand += 2*log(K[i*m+i]);
-      F77_NAME(dpotri)(lower, &m, K, &m, &info FCONE); if(info != 0){error("c++ error: Cholesky inverse failed in spGLM\n");}
+      F77_NAME(dpotri)(lower, &m, K, &m, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: Cholesky inverse failed in spGLM\n");}
       
       //make \tild{w}
       F77_NAME(dsymv)(lower, &m, &one, K, &m, w_strCand, &incOne, &zero, tmp_m, &incOne FCONE);     
@@ -305,7 +309,7 @@ extern "C" {
       }else if(family == "poisson"){
 	logPostCand += poisson_logpost(n, Y, tmp_n, wCand, weights);
       }else{
-	error("c++ error: family misspecification in spGLM\n");
+	Rf_error("c++ Rf_error: family misspecification in spGLM\n");
       }
 
       //(-1/2) * tmp_n` *  C^-1 * tmp_n
@@ -381,23 +385,23 @@ extern "C" {
     
     int nResultListObjs = 4;
 
-    PROTECT(result = allocVector(VECSXP, nResultListObjs)); nProtect++;
-    PROTECT(resultNames = allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(result = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(resultNames = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
 
    //samples
     SET_VECTOR_ELT(result, 0, samples_r);
-    SET_VECTOR_ELT(resultNames, 0, mkChar("p.beta.theta.samples")); 
+    SET_VECTOR_ELT(resultNames, 0, Rf_mkChar("p.beta.theta.samples")); 
 
     SET_VECTOR_ELT(result, 1, accept_r);
-    SET_VECTOR_ELT(resultNames, 1, mkChar("acceptance"));
+    SET_VECTOR_ELT(resultNames, 1, Rf_mkChar("acceptance"));
     
     SET_VECTOR_ELT(result, 2, w_r);
-    SET_VECTOR_ELT(resultNames, 2, mkChar("p.w.samples"));
+    SET_VECTOR_ELT(resultNames, 2, Rf_mkChar("p.w.samples"));
 
     SET_VECTOR_ELT(result, 3, w_str_r);
-    SET_VECTOR_ELT(resultNames, 3, mkChar("p.w.knots.samples"));
+    SET_VECTOR_ELT(resultNames, 3, Rf_mkChar("p.w.knots.samples"));
   
-    namesgets(result, resultNames);
+    Rf_namesgets(result, resultNames);
    
     //unprotect
     UNPROTECT(nProtect);
