@@ -1,3 +1,7 @@
+#ifndef R_NO_REMAP
+#  define R_NO_REMAP
+#endif
+
 #define USE_FC_LEN_T
 #include <algorithm>
 #include <string>
@@ -107,7 +111,7 @@ extern "C" {
       if(amcmc){
 	Rprintf("Using adaptive MCMC.\n\n");
 	Rprintf("\tNumber of batches %i.\n", nBatch);
-	Rprintf("\tBatch length %i.\n", batchLength);
+	Rprintf("\tBatch Rf_length %i.\n", batchLength);
 	Rprintf("\tTarget acceptance rate %.5f.\n", acceptRate);
 	Rprintf("\n");
       }else{
@@ -214,10 +218,10 @@ extern "C" {
 
     //return stuff  
     SEXP samples_r, accept_r, tuning_r, betaSamples_r;
-    PROTECT(samples_r = allocMatrix(REALSXP, nParams, nSamples)); nProtect++; 
-    PROTECT(accept_r = allocMatrix(REALSXP, nParams, nBatch)); nProtect++; 
-    PROTECT(tuning_r = allocMatrix(REALSXP, nParams, nBatch)); nProtect++;
-    PROTECT(betaSamples_r = allocMatrix(REALSXP, p, nSamples)); nProtect++; 
+    PROTECT(samples_r = Rf_allocMatrix(REALSXP, nParams, nSamples)); nProtect++; 
+    PROTECT(accept_r = Rf_allocMatrix(REALSXP, nParams, nBatch)); nProtect++; 
+    PROTECT(tuning_r = Rf_allocMatrix(REALSXP, nParams, nBatch)); nProtect++;
+    PROTECT(betaSamples_r = Rf_allocMatrix(REALSXP, p, nSamples)); nProtect++; 
     
     /*****************************************
        Set-up MCMC alg. vars. matrices etc.
@@ -264,8 +268,8 @@ extern "C" {
       betaCInvMu = (double *) R_alloc(p, sizeof(double));
       
       F77_NAME(dcopy)(&pp, betaC, &incOne, betaCInv, &incOne);
-      F77_NAME(dpotrf)(lower, &p, betaCInv, &p, &info FCONE); if(info != 0){error("c++ error: dpotrf failed\n");}
-      F77_NAME(dpotri)(lower, &p, betaCInv, &p, &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
+      F77_NAME(dpotrf)(lower, &p, betaCInv, &p, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: dpotrf failed\n");}
+      F77_NAME(dpotri)(lower, &p, betaCInv, &p, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: dpotri failed\n");}
       
       F77_NAME(dsymv)(lower, &p, &one, betaCInv, &p, betaMu, &incOne, &zero, betaCInvMu, &incOne FCONE);      
     }
@@ -330,7 +334,7 @@ extern "C" {
 	      }
 	    }
 	    
-	    F77_NAME(dpotrf)(lower, &m, tmp_mm, &m, &info FCONE); if(info != 0){error("c++ error: dpotrf failed\n");}//L_K
+	    F77_NAME(dpotrf)(lower, &m, tmp_mm, &m, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: dpotrf failed\n");}//L_K
 	    F77_NAME(dcopy)(&nm, P, &incOne, H, &incOne);
 	    
 	    F77_NAME(dtrsm)(lside, lower, ntran, nUnit, &m, &n, &one, tmp_mm, &m, H, &m FCONE FCONE FCONE FCONE);
@@ -362,7 +366,7 @@ extern "C" {
 	    }
 	  }
 	  
-	  F77_NAME(dpotrf)(lower, &m, K, &m, &info FCONE); if(info != 0){error("c++ error: dpotrf failed\n");}//L
+	  F77_NAME(dpotrf)(lower, &m, K, &m, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: dpotrf failed\n");}//L
 	  
 	  F77_NAME(dtrsm)(lside, lower, ntran, nUnit, &m, &n, &one, K, &m, H, &m FCONE FCONE FCONE FCONE);//LH = W'
 	  
@@ -380,7 +384,7 @@ extern "C" {
 	    tmp_mm[k*m+k] += 1.0; //J
 	  }
 	  
-	  F77_NAME(dpotrf)(lower, &m, tmp_mm, &m, &info FCONE); if(info != 0){error("c++ error: dpotrf failed\n");}//L_J
+	  F77_NAME(dpotrf)(lower, &m, tmp_mm, &m, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: dpotrf failed\n");}//L_J
 	  
 	  det = 0;
 	  for(k = 0; k < n; k++){
@@ -469,8 +473,8 @@ extern "C" {
 	  }
  	  
 	  //B
-	  F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE); if(info != 0){error("c++ error: Cholesky failed\n");}
-	  F77_NAME(dpotri)(lower, &p, tmp_pp, &p, &info FCONE); if(info != 0){error("c++ error: Cholesky inverse failed\n");}
+	  F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: Cholesky failed\n");}
+	  F77_NAME(dpotri)(lower, &p, tmp_pp, &p, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: Cholesky inverse failed\n");}
    
 	  //b
 	  F77_NAME(dgemv)(ytran, &n, &p, &one, tmp_np, &n, tmp_n, &incOne, &zero, tmp_p, &incOne FCONE); //V'\tilda{y}
@@ -486,7 +490,7 @@ extern "C" {
 	  }
 	  
 	  F77_NAME(dsymv)(lower, &p, &one, tmp_pp, &p, tmp_p, &incOne, &zero, tmp_p2, &incOne FCONE); //Bb
-	  F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE); if(info != 0){error("c++ error: dpotrf failed\n");}
+	  F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE); if(info != 0){Rf_error("c++ Rf_error: dpotrf failed\n");}
 
 	}//end updateBeta
 
@@ -583,23 +587,23 @@ extern "C" {
     SEXP result_r, resultName_r;
     int nResultListObjs = 4;
 
-    PROTECT(result_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
-    PROTECT(resultName_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(result_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(resultName_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
 
     //samples
     SET_VECTOR_ELT(result_r, 0, samples_r);
-    SET_VECTOR_ELT(resultName_r, 0, mkChar("p.theta.samples")); 
+    SET_VECTOR_ELT(resultName_r, 0, Rf_mkChar("p.theta.samples")); 
 
     SET_VECTOR_ELT(result_r, 1, accept_r);
-    SET_VECTOR_ELT(resultName_r, 1, mkChar("acceptance"));
+    SET_VECTOR_ELT(resultName_r, 1, Rf_mkChar("acceptance"));
 
     SET_VECTOR_ELT(result_r, 2, tuning_r);
-    SET_VECTOR_ELT(resultName_r, 2, mkChar("tuning"));
+    SET_VECTOR_ELT(resultName_r, 2, Rf_mkChar("tuning"));
     
     SET_VECTOR_ELT(result_r, 3, betaSamples_r);
-    SET_VECTOR_ELT(resultName_r, 3, mkChar("p.beta.samples"));
+    SET_VECTOR_ELT(resultName_r, 3, Rf_mkChar("p.beta.samples"));
   
-    namesgets(result_r, resultName_r);
+    Rf_namesgets(result_r, resultName_r);
    
     //unprotect
     UNPROTECT(nProtect);
